@@ -85,7 +85,7 @@ class CmeClient(AbstractClient):
 
 
     def CreateLink(self, request):
-        """创建素材链接或分类路径链接，将源资源信息链接到目标。
+        """创建媒体链接或分类路径链接，将源资源信息链接到目标。
 
         :param request: Request instance for CreateLink.
         :type request: :class:`tencentcloud.cme.v20191029.models.CreateLinkRequest`
@@ -653,7 +653,7 @@ class CmeClient(AbstractClient):
 
 
     def DescribeTeams(self, request):
-        """获取指定团队的信息。
+        """获取指定团队的信息，拉取团队信息列表。
 
         :param request: Request instance for DescribeTeams.
         :type request: :class:`tencentcloud.cme.v20191029.models.DescribeTeamsRequest`
@@ -681,7 +681,7 @@ class CmeClient(AbstractClient):
 
 
     def ExportVideoByEditorTrackData(self, request):
-        """使用在线编辑轨道数据直接导出视频。
+        """使用视频合成协议导出视频，支持导出到CME云媒资和VOD云媒资。
 
         :param request: Request instance for ExportVideoByEditorTrackData.
         :type request: :class:`tencentcloud.cme.v20191029.models.ExportVideoByEditorTrackDataRequest`
@@ -793,7 +793,9 @@ class CmeClient(AbstractClient):
 
 
     def GenerateVideoSegmentationSchemeByAi(self, request):
-        """发起视频智能拆条任务，支持智能生成和平精英集锦、王者荣耀集锦、足球集锦、篮球集锦 、人物集锦、新闻拆条等任务。
+        """<li>发起视频智能拆条任务，支持智能生成和平精英集锦、王者荣耀集锦、足球集锦、篮球集锦 、人物集锦、新闻拆条等任务。</li>
+        <li>和平精英集锦和王者荣耀集锦根据击杀场景进行拆条，足球集锦和篮球集锦根据进球场景进行拆条，人物集锦根据人物人脸特征进行拆条，新闻拆条根据导播进行拆条。</li>
+        <li>【本接口内测中，暂不建议使用】</li>
 
         :param request: Request instance for GenerateVideoSegmentationSchemeByAi.
         :type request: :class:`tencentcloud.cme.v20191029.models.GenerateVideoSegmentationSchemeByAiRequest`
@@ -849,7 +851,7 @@ class CmeClient(AbstractClient):
 
 
     def ImportMaterial(self, request):
-        """将云点播媒资文件导入到云剪素材库。
+        """将云点播媒资文件导入到云剪媒体资源库。
 
         :param request: Request instance for ImportMaterial.
         :type request: :class:`tencentcloud.cme.v20191029.models.ImportMaterialRequest`
@@ -877,7 +879,7 @@ class CmeClient(AbstractClient):
 
 
     def ImportMediaToProject(self, request):
-        """将云点播中的媒资添加到素材库中，供后续视频编辑使用。
+        """将云点播中的媒资或者用户自有媒资文件添加到媒体库中，跟项目关联，供后续视频编辑使用。目前仅普通编辑项目和智能视频拆条项目有效。
 
         :param request: Request instance for ImportMediaToProject.
         :type request: :class:`tencentcloud.cme.v20191029.models.ImportMediaToProjectRequest`
